if(isPackage(waterBricks) && !$forceReExec) {
	//Don't try to register the event or package more than once unless forced to by the user (see comment below).
	echo("Package \"waterBricks\" already exists, ending execution");
	return;
}

if(forceRequiredAddOn("Brick_Large_Cubes") == $Error::AddOn_NotFound) {
	warn("ERROR: Event_WaterBricks - required add-on Brick_Large_Cubes not found");
	return;
}

if(isFile("Add-Ons/System_ReturnToBlockland/server.cs")) {
	if(!$RTB::RTBR_ServerControl_Hook)
		exec("Add-Ons/System_ReturnToBlockland/RTBR_ServerControl_Hook.cs");
		RTB_registerPref("Load Physical Zones", "Water Events", "Pref::Server::fxWaterToRealWater", "bool", "Event_WaterBricks", false, false, true);
		//RTB_registerPref("Pref Name","Category","Pref","Var Type","Your Mod Name","Default Pref Value","Requires Server Restart","Host Only");
} else
	$Pref::Server::fxWaterToRealWater = false;

registerOutputEvent(fxDTSBrick, "makeWater", "bool" TAB "float 0 100 1 0");

function fxDTSBrick::makeWater(%this, %isWater, %current) {
	if(%isWater && !isObject(%this.physicalZone)) {
		%this.setColliding(0);
		%this.setRayCasting(0);
		%this.setShapeFX(2);
		%this.createWaterZone();
		if(!isObject($LoadingBricks_Client)) {
			if(%this.getNumDownBricks() == 1) {
				%downBrick = %this.getDownBrick(0);
				if(isObject(%downBrick.physicalZone))
					%downBrick.setRendering(false);
			}
			if(%this.getNumUpBricks() == 1) {
				%upBrick = %this.getUpBrick(0);
				if(isObject(%upBrick.physicalZone))
					%this.setRendering(false);
			}
		}
	}
	else if(!%isWater && isObject(%this.physicalZone)) {
		brick8xWaterData::onDeath(%this.getDataBlock(), %this);
		%this.setShapeFX(0);
		%this.setRayCasting(true);
		%this.setColliding(true);
		%this.setRendering(true);
	}
	if(isObject(%this.physicalZone))
		%this.physicalZone.setAppliedForce(vectorScale(%this.getForwardVector(), %current * 100));
}

if(isPackage(waterBricks))
	deactivatePackage(waterBricks);
	//Modifications to this Add-On made in-game won't be lost by re-executing this script,
	//however if they mess something up, they should have a way of restoring the default script
	//without re-starting the server. In this case, they can set $forceReExec to true, and
	//everything (event, ::makeWater() and package) will be re-defined.
package waterBricks {
	function fxDTSBrickData::onLoadPlant(%this, %obj) {
		if(%obj.shapeFxID == 2 && $Pref::Server::fxWaterToRealWater)
			brick8xWaterData::onLoadPlant(%this, %obj);
		return parent::onPlant(%this, %obj);
	}
	function fxDTSBrickData::onPlant(%this, %obj) {
		if(%obj.shapeFxID == 2 && $Pref::Server::fxWaterToRealWater)
			brick8xWaterData::onPlant(%this, %obj);
		return parent::onPlant(%this, %obj);
	}
	function fxDTSBrickData::onDeath(%this, %obj) {
		if(isObject(%obj.physicalZone))
			brick8xWaterData::onDeath(%this, %obj);
		return parent::onDeath(%this, %obj);
	}
	function fxDTSBrickData::onRemove(%this, %obj) {
		if(isObject(%obj.physicalZone))
			brick8xWaterData::onRemove(%this, %obj);
		return parent::onRemove(%this, %obj);
	}
	function fxDTSBrickData::onColorChange(%this, %obj) {
		if(isObject(%obj.physicalZone)) {
			%color = getColorIDTable(%obj.colorID);
			%rgb = getWords(%color, 0, 2);
			%a = getWord(%color, 3) * 0.75;
			%obj.physicalZone.setWaterColor(%rgb SPC %a);
		}
		return parent::onColorChange(%this, %obj);
	}
	function fxDTSBrickData::onFakeDeath(%this, %obj) {
		if(isObject(%obj.physicalZone))
			%obj.physicalZone.deactivate();
		return parent::onFakeDeath(%this, %obj);
	}
	function fxDTSBrickData::onClearFakeDeath(%this, %obj) {
		if(isObject(%obj.physicalZone)) {
			%obj.physicalZone.activate();
			if(%obj.shapeFxID == 2) {
				%obj.setColliding(false);
				%obj.setRayCasting(false);
			}
		}
		return parent::onClearFakeDeath(%this, %obj);
	}
	function fxDTSBrickData::disappear(%this, %obj, %time) {
		if(isObject(%obj.physicalZone)) {
			if(%time) {
				%obj.physicalZone.activate();
				if(%obj.shapeFxID == 2) {
					%obj.setColliding(false);
					%obj.setRayCasting(false);
				}
			} else
				%obj.physicalZone.deactivate();
		}
		return parent::disappear(%this, %obj, %time);
	}
	function fxDTSBrickData::reappear(%this, %obj) {
		if(isObject(%obj.physicalZone)) {
			%obj.physicalZone.activate();
			if(%obj.shapeFxID == 2) {
				%obj.setColliding(false);
				%obj.setRayCasting(false);
			}
		}
		return parent::reappear(%this, %obj);
	}
};
activatePackage(waterBricks);
